@@ -1,6 +1,6 @@
 #!/bin/bash
 
-#Copyright (C) 2006 - 2008 NTT DATA Corporation
+#Copyright (C) since 2006 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -23,9 +23,22 @@ if [ ${EXEC_USER} != "hinemos" -a ${EXEC_USER} != "root" ]; then
 fi
 
 # check on option
+if [ $# = 0 ] ;then
+    if [ ! -d ${JBOSS_HOME}/server/default ] ;then
+        echo "ERROR JBoss is high availability composition."
+        exit 1
+    fi
+fi
+
 for OPTION in "$@"
 do
 	case $OPTION in
+		-a)
+			if [ ! -d ${JBOSS_HOME}/server/all ] ;then
+				echo "ERROR JBoss is not high availability composition. "
+				exit 1
+			fi
+			;;
 		-c)
 			;;
 		*)
@@ -61,9 +74,12 @@ echo "waiting for jboss to start..."
 for OPTION in "$@"
 do
 	case $OPTION in
+		-a)
+			ALL_OPTION="-c all"
+			;;
 		-c)
 			echo "After the JMS message is annulled, JBoss is started. "
-			rm -rf ${HINEMOS_HOME}/jboss-4.2.2.GA/server/default/data/hypersonic/*
+			rm -rf ${JBOSS_HOME}/server/default/data/hypersonic/*
 			;;
 		*)
 			;;
@@ -71,7 +87,7 @@ do
 done
 
 
-nohup ${HINEMOS_HOME}/jboss-4.2.2.GA/bin/run_hinemos.sh -b ${IP_ADDRESS} > ${HINEMOS_HOME}/var/log/jboss_stdout.log &
+nohup ${JBOSS_HOME}/bin/run_hinemos.sh ${ALL_OPTION} -b ${IP_ADDRESS} > ${HINEMOS_HOME}/var/log/jboss_stdout.log &
 
 TODAY=`date +%Y-%m-%d`
 TIME_COUNT=0
@@ -123,6 +139,11 @@ done
 
 #copy jboss boot.log to /opt/hinemos/var/log/boot.log.XXXX-XX-XX
 SDATE=`date +%Y-%m-%d`
-cat ${HINEMOS_HOME}/jboss-4.2.2.GA/server/default/log/boot.log >>${HINEMOS_HOME}/var/log/boot.log.${SDATE}
+
+if [ -n "${ALL_OPTION}" ] ; then
+	cat ${JBOSS_HOME}/server/all/log/boot.log >>${HINEMOS_HOME}/var/log/boot.log.${SDATE}
+else
+	cat ${JBOSS_HOME}/server/default/log/boot.log >>${HINEMOS_HOME}/var/log/boot.log.${SDATE}
+fi
 
 echo "jboss started"
