@@ -1,6 +1,6 @@
 #!/bin/sh
 
-#Copyright (C) 2006 - 2008 NTT DATA Corporation
+#Copyright (C) since 2006 NTT DATA Corporation
 #
 #This program is free software; you can redistribute it and/or
 #Modify it under the terms of the GNU General Public License
@@ -39,7 +39,7 @@ if [ -f ${HINEMOS_LDAP_PID} ] ; then
 fi
 
 echo "waiting for slapd to start..."
-${HINEMOS_HOME}/openldap-2.3.39/libexec/slapd -h "ldap://0.0.0.0:24000/"
+${LDAP}/libexec/slapd -h "ldap://0.0.0.0:24000/"
 REVAL=$?
 if [ $REVAL -ne 0 ]; then
         echo "ERROR  It may not start normally."
